@@ -19,14 +19,13 @@ header = {"Content-Type": "application/json"}
 
 
 def trace():
-    os.environ["SKIP_ADAPTER"] = "False"
+    os.environ["SKIP_ADAPTER"] = "True"
     headers = dict()
     probe_url = f'https://proberunner.internal.mum1-stage.zetaapps.in/trace/headers'
     response = requests.get(url=probe_url, headers=header)
     os.environ["SKIP_ADAPTER"] = "False"
     try:
         headers = response.json()['traceHeaders']
-        print(headers)
     except:
         return headers
     return headers
@@ -35,10 +34,6 @@ def trace():
 @decorator
 def adaptor(func, flow_id=None, *args, **kwargs):
     os.environ["FLOW_ID"] = flow_id
-    if args:
-        for i in args:
-            if isinstance(i, dict):
-                i.update(trace())
     return func(*args, **kwargs)
 
 
@@ -58,6 +53,8 @@ def logged_request(method, url, **kwargs):
         start_time = int(time.time() * 1000)
 
         try:
+            headerDict:dict = kwargs.get('headers')
+            headerDict.update(trace())
             response = original_request_method(method, url, **kwargs)
             request = response.request
         finally:
